
; ATMega8515

; Version v0.1 27.03.2007 M'Soft Berlin

; programmierte FUSE: SUT0  - Quarz - Slowly Rising Power 

; Definitionen

; Belegungen der Atmel-Ports:

;*****************************************************************

;	PA0		0/D0	ext RAM
;	PA1		1/D1	ext RAM
;	PA2		2/D2	ext RAM
;	PA3		3/D3	ext RAM
;	PA4		4/D4	ext RAM
;	PA5		5/D5	ext RAM
;	PA6		6/D6	ext RAM
;	PA7		7/D7	ext RAM

;	PB0		T0/OC0
;	PB1		T1
;	PB2		AIN0
;	PB3		AIN1
;	PB4		SS
;	PB5		MOSI
;	PB6		MISO
;	PB7		SCK

;	PC0		A8		ext RAM						
;	PC1		A9		ext RAM		
;	PC2		A10		ext RAM		
;	PC3		A11		ext RAM	
;	PC4		A12		ext RAM
;	PC5		A13
;	PC6		A14
;	PC7		A15		ext RAM	CS			

;	PD0		RxD		
;	PD1		TxD		
;	PD2		INT0
;	PD3		INT1
;	PD4		XCK
;	PD5		OC1A
;	PD6		WR		ext RAM /WR
;	PD7		RD		ext RAM /OE

;	PE0		INT2
;	PE1		ALE		ext RAM Latch
;	PE2		OC1B

;*****************************************************************

;--- Allgemeines -----------------------------------------------

.equ    F_CPU           = 16000000
.equ    CYCLES_PER_US   = ((F_CPU+500000)/1000000)

.equ	IRQ_TIME		= 5				; IRQ-Zeit in !!! s !!!

.equ	VORTEILER		= 1
.equ	COUNT_IN		= F_CPU/VORTEILER	; Vorteiler 1 - 16000000Hz

.equ    TCONST_TIME     = 80-1				; / 80 = 200kHz 								
								
; Interne Konstanten

.equ	LINE_LEN		= 480
.equ	X_SIZE			= 60
.equ	Y_SIZE			= 64

.equ	FONT_WIDTH		= 16
.equ	FONT_HEIGHT		= 16

;**************************** Ram-Reservierungen ******************

;--- Internes Ram -------------------------------------------------

.DSEG
.ORG	$8000

DDRAM:	.byte	X_SIZE*Y_SIZE				;DDRAM

;****************** Port-Zuordnung und Register-Bits ******************

.equ	LCD_DATA	= PB5					; 1 - Datenbit		- SPI MOSI
.equ	LCD_CLOCK	= PB7					; 5 - Pixelclock	- SI CLOCK

.equ	LCD_PORT	= PORTD
.equ	LCD_PIN		= PIND

.equ	LCD_FLM		= PD1					; 2 - First Line Marker (VSync)
.equ	LCD_M		= PD2					; 3 - AC-Drive
.equ	LCD_LP		= PD3					; 4 - Latch-Puls (HSync)

.equ	M_MASK		= (1<<LCD_M)

;--- lower Register -----------------------------------------------

.def	MUL_LOW		= r0
.def	MUL_HIGH	= r1

.def	REGSAVE		= r2

.def	M_MASK_REG	= r3

;--- higher Register ----------------------------------------------

.def	X_REG		= r16
.def	Y_REG		= r17

.def	TEMP_IRQ	= r18

.def    TEMP_0      = r22                   ; temporres  8Bit-Register
.def    TEMP_1      = r23                   ; temporres  8Bit-Register
.def    TEMP_2      = r24                   ; temporres  8Bit-Register
.def    TEMP_3      = r25                   ; temporres  8Bit-Register

	; X-Register zeigt auf DDRAM fr Displayrefresh
	; Y-Register enthlt Cursor-Position 0

; r26/r27 - X, r28/r29 - Y, r30/r31 - Z

;--- Macros -------------------------------------------------------

.macro  load_p                  		    ; ldt 16Bit @1 nach @0 High und @0 Low
        ldi     @0H,HIGH(@1)
        ldi     @0L,LOW(@1)
.endmacro


